@@ -49,6 +49,13 @@ def _activate(vwo_instance, campaign_key, user_id, **kwargs):
     """
 
     vwo_instance.logger.set_api(API_METHODS.ACTIVATE)
+
+    if vwo_instance.is_opted_out:
+        vwo_instance.logger.log(
+            LogLevelEnum.INFO, LogMessageEnum.INFO_MESSAGES.API_NOT_ENABLED.format(file=FILE, api=API_METHODS.ACTIVATE)
+        )
+
+        return None
     # Retrieve custom variables
     custom_variables = kwargs.get("custom_variables")
     variation_targeting_variables = kwargs.get("variation_targeting_variables")
