@@ -13,6 +13,11 @@
 # limitations under the License.
 
 from ..constants.constants import API_METHODS
+from ..enums.file_name_enum import FileNameEnum
+from ..enums.log_level_enum import LogLevelEnum
+from ..enums.log_message_enum import LogMessageEnum
+
+FILE = FileNameEnum.Api.FlushEvents
 
 
 def _flush_events(vwo_instance, mode):
@@ -23,5 +28,16 @@ def _flush_events(vwo_instance, mode):
         mode(string): In sync mode, function makes a synchronous call before exiting
             In async mode, function spawns a thread to sync to VWO and exits
     """
-    vwo_instance.logger.set_api(API_METHODS.FLUSH_EVENTS)
-    vwo_instance.event_dispatcher.flush_queue(manual=True, mode=mode)
+    if vwo_instance.is_opted_out:
+        vwo_instance.logger.log(
+            LogLevelEnum.INFO,
+            LogMessageEnum.INFO_MESSAGES.API_NOT_ENABLED.format(file=FILE, api=API_METHODS.FLUSH_EVENTS),
+        )
+
+        return False
+
+    if vwo_instance.is_event_batching_enabled:
+        vwo_instance.logger.set_api(API_METHODS.FLUSH_EVENTS)
+        vwo_instance.event_dispatcher.flush_queue(manual=True, mode=mode)
+
+        return True
